==> waves-core-1.1.4.tar.gz: waves-core-1.1.4/waves/wcore/api/v2/serializers/inputs.py <==
from __future__ import unicode_literals

from rest_framework import serializers
from rest_framework.fields import empty

from waves.wcore.api.share import DynamicFieldsModelSerializer, RecursiveField
from waves.wcore.models.inputs import *
from .fields import CommaSeparatedListField, ListElementField


class AParamSerializer(serializers.ModelSerializer):
    class Meta:
        fields = ['when_value', 'label', 'default', 'api_name', 'type', 'mandatory', 'description', 'multiple',
                  'edam_formats', 'edam_datas', 'dependents_inputs']
        model = AParam

    mandatory = serializers.NullBooleanField(source='required')
    description = serializers.CharField(source='help_text')
    edam_formats = CommaSeparatedListField()
    edam_datas = CommaSeparatedListField()
    dependents_inputs = RecursiveField(many=True, read_only=True)

    def to_representation(self, instance):
        repr_initial = super(AParamSerializer, self).to_representation(instance)
        if instance.dependents_inputs.count() == 0:
            repr_initial.pop('dependents_inputs')
        if instance.when_value is None:
            repr_initial.pop('when_value')
        return repr_initial

    @staticmethod
    def get_type(param):
        return param.type


class TextParamSerializer(AParamSerializer):
    class Meta(AParamSerializer.Meta):
        model = TextParam
        fields = AParamSerializer.Meta.fields + ['max_length']

    max_length = serializers.IntegerField()


class IntegerSerializer(AParamSerializer):
    class Meta(AParamSerializer.Meta):
        model = IntegerParam
        fields = AParamSerializer.Meta.fields + ['min_val', 'max_val']

    default = serializers.IntegerField()
    min_val = serializers.IntegerField()
    max_val = serializers.IntegerField()


class BooleanSerializer(AParamSerializer):
    class Meta(AParamSerializer.Meta):
        model = BooleanParam
        fields = AParamSerializer.Meta.fields + ['true_value', 'false_value']


class DecimalSerializer(AParamSerializer):
    class Meta:
        model = DecimalParam
        fields = AParamSerializer.Meta.fields + ['min_val', 'max_val']

    default = serializers.DecimalField(decimal_places=3, max_digits=50, coerce_to_string=False)
    min_val = serializers.DecimalField(decimal_places=3, max_digits=50, coerce_to_string=False)
    max_val = serializers.DecimalField(decimal_places=3, max_digits=50, coerce_to_string=False)


class FileSerializer(AParamSerializer):
    class Meta(AParamSerializer.Meta):
        model = FileInput
        fields = AParamSerializer.Meta.fields + ['max_size', 'allowed_extensions']


class ListSerialzer(AParamSerializer):
    class Meta(AParamSerializer.Meta):
        model = ListParam
        fields = AParamSerializer.Meta.fields + ['values_list']

    values_list = ListElementField(source='list_elements')


class InputSerializer(DynamicFieldsModelSerializer):
    """ Serialize JobInput """

    class Meta:
        model = AParam
        queryset = AParam.objects.all()
        fields = ('label', 'name', 'default', 'type', 'mandatory', 'help_text', 'multiple', 'dependents_inputs',
                  'api_name')
        extra_kwargs = {
            'url': {'view_name': 'wapi:api_v2:waves-services-detail', 'lookup_field': 'api_name'}
        }

    def __init__(self, instance=None, data=empty, **kwargs):
        super(InputSerializer, self).__init__(instance, data, **kwargs)

    def to_representation(self, obj):
        """ Return representation for an Input, including dependents inputs if needed """
        if isinstance(obj, FileInput):
            return FileSerializer(obj, context=self.context).to_representation(obj)
        elif isinstance(obj, ListParam):
            return ListSerialzer(obj, context=self.context).to_representation(obj)
        elif isinstance(obj, BooleanParam):
            return BooleanSerializer(obj, context=self.context).to_representation(obj)
        elif isinstance(obj, IntegerParam):
            return IntegerSerializer(obj, context=self.context).to_representation(obj)
        elif isinstance(obj, DecimalParam):
            return DecimalSerializer(obj, context=self.context).to_representation(obj)
        elif isinstance(obj, TextParam):
            return TextParamSerializer(obj, context=self.context).to_representation(obj)
        else:
            raise Exception('Type not recognized')


class RelatedInputSerializer(InputSerializer):
    """ Serialize a dependent Input (RelatedParam models) """

    class Meta:
        fields = InputSerializer.Meta.fields

    def to_representation(self, instance):
        """ Return representation of a Related Input """
        initial_repr = super(RelatedInputSerializer, self).to_representation(instance)
        return {instance.when_value: initial_repr}


class ConditionalInputSerializer(InputSerializer):
    """ Serialize inputs if it's a conditional one """

    class Meta:
        model = AParam
        fields = ('label', 'name', 'default', 'param_type', 'cmd_format', 'mandatory', 'help_text', 'multiple',
                  'when')

    when = RelatedInputSerializer(source='dependents_inputs', many=True, read_only=True)

==> waves-core-1.6.2.tar.gz: waves-core-1.6.2/waves/wcore/api/v2/serializers/inputs.py <==
from __future__ import unicode_literals

from rest_framework import serializers
from rest_framework.fields import empty

from waves.wcore.api.share import DynamicFieldsModelSerializer, RecursiveField
from waves.wcore.models.inputs import AParam, TextParam, ListParam, BooleanParam, IntegerParam, FileInput, DecimalParam
from .fields import CommaSeparatedListField, ListElementField


class AParamSerializer(serializers.ModelSerializer):
    class Meta:
        fields = ['when_value', 'label', 'default', 'type', 'mandatory', 'description', 'multiple',
                  'edam_formats', 'edam_datas', 'dependents_inputs']
        model = AParam

    mandatory = serializers.NullBooleanField(source='required')
    description = serializers.CharField(source='help_text')
    edam_formats = CommaSeparatedListField()
    edam_datas = CommaSeparatedListField()
    dependents_inputs = RecursiveField(many=True, read_only=True)

    def to_representation(self, instance):
        repr_initial = super(AParamSerializer, self).to_representation(instance)
        if instance.dependents_inputs.count() == 0:
            repr_initial.pop('dependents_inputs')
        if instance.when_value is None:
            repr_initial.pop('when_value')
        return repr_initial

    @staticmethod
    def get_type(param):
        return param.type


class TextParamSerializer(AParamSerializer):
    class Meta(AParamSerializer.Meta):
        model = TextParam
        fields = AParamSerializer.Meta.fields + ['max_length']

    max_length = serializers.IntegerField()


class IntegerSerializer(AParamSerializer):
    class Meta(AParamSerializer.Meta):
        model = IntegerParam
        fields = AParamSerializer.Meta.fields + ['min_val', 'max_val']

    default = serializers.IntegerField()
    min_val = serializers.IntegerField()
    max_val = serializers.IntegerField()


class BooleanSerializer(AParamSerializer):
    class Meta(AParamSerializer.Meta):
        model = BooleanParam
        fields = AParamSerializer.Meta.fields + ['true_value', 'false_value']


class DecimalSerializer(AParamSerializer):
    class Meta:
        model = DecimalParam
        fields = AParamSerializer.Meta.fields + ['min_val', 'max_val']

    default = serializers.DecimalField(decimal_places=3, max_digits=50, coerce_to_string=False)
    min_val = serializers.DecimalField(decimal_places=3, max_digits=50, coerce_to_string=False)
    max_val = serializers.DecimalField(decimal_places=3, max_digits=50, coerce_to_string=False)


class FileSerializer(AParamSerializer):
    class Meta(AParamSerializer.Meta):
        model = FileInput
        fields = AParamSerializer.Meta.fields + ['max_size', 'allowed_extensions']


class ListSerialzer(AParamSerializer):
    class Meta(AParamSerializer.Meta):
        model = ListParam
        fields = AParamSerializer.Meta.fields + ['values_list']

    values_list = ListElementField(source='list_elements')


class InputSerializer(DynamicFieldsModelSerializer):
    """ Serialize JobInput """

    class Meta:
        model = AParam
        queryset = AParam.objects.all()
        fields = ('label', 'name', 'default', 'type', 'mandatory', 'help_text', 'multiple', 'dependents_inputs',)
        extra_kwargs = {
            'url': {'view_name': 'wapi:v2:waves-services-detail', 'lookup_field': 'api_name'}
        }

    def __init__(self, instance=None, data=empty, **kwargs):
        super(InputSerializer, self).__init__(instance, data, **kwargs)

    def to_representation(self, obj):
        """ Return representation for an Input, including dependents inputs if needed """
        if isinstance(obj, FileInput):
            return FileSerializer(obj, context=self.context).to_representation(obj)
        elif isinstance(obj, ListParam):
            return ListSerialzer(obj, context=self.context).to_representation(obj)
        elif isinstance(obj, BooleanParam):
            return BooleanSerializer(obj, context=self.context).to_representation(obj)
        elif isinstance(obj, IntegerParam):
            return IntegerSerializer(obj, context=self.context).to_representation(obj)
        elif isinstance(obj, DecimalParam):
            return DecimalSerializer(obj, context=self.context).to_representation(obj)
        elif isinstance(obj, TextParam):
            return TextParamSerializer(obj, context=self.context).to_representation(obj)
        else:
            raise Exception('Type not recognized')


class RelatedInputSerializer(InputSerializer):
    """ Serialize a dependent Input (RelatedParam models) """

    class Meta:
        fields = InputSerializer.Meta.fields

    def to_representation(self, instance):
        """ Return representation of a Related Input """
        initial_repr = super(RelatedInputSerializer, self).to_representation(instance)
        return {instance.when_value: initial_repr}


class ConditionalInputSerializer(InputSerializer):
    """ Serialize inputs if it's a conditional one """

    class Meta:
        model = AParam
        fields = ('label', 'name', 'default', 'param_type', 'cmd_format', 'mandatory', 'help_text', 'multiple',
                  'when')

    when = RelatedInputSerializer(source='dependents_inputs', many=True, read_only=True)
